You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@maven.apache.org by mi...@apache.org on 2018/05/20 11:03:11 UTC

[maven] branch MNG-6410 updated: Rename method name to the option name

This is an automated email from the ASF dual-hosted git repository.

michaelo pushed a commit to branch MNG-6410
in repository https://gitbox.apache.org/repos/asf/maven.git


The following commit(s) were added to refs/heads/MNG-6410 by this push:
     new 172c1af  Rename method name to the option name
172c1af is described below

commit 172c1afdaccf012a20666ac978cc8fb5a0472e46
Author: Michael Osipov <mi...@apache.org>
AuthorDate: Sun May 20 13:02:37 2018 +0200

    Rename method name to the option name
---
 .../main/java/org/apache/maven/cli/MavenCli.java   | 24 +++++++++++-----------
 1 file changed, 12 insertions(+), 12 deletions(-)

diff --git a/maven-embedder/src/main/java/org/apache/maven/cli/MavenCli.java b/maven-embedder/src/main/java/org/apache/maven/cli/MavenCli.java
index 31a6515..ca8e040 100644
--- a/maven-embedder/src/main/java/org/apache/maven/cli/MavenCli.java
+++ b/maven-embedder/src/main/java/org/apache/maven/cli/MavenCli.java
@@ -1007,7 +1007,7 @@ public class MavenCli
                 slf4jLogger.error( "" );
                 slf4jLogger.error( "After correcting the problems, you can resume the build with the command" );
                 slf4jLogger.error( buffer().a( "  " ).strong( "mvn <goals> -rf "
-                    + getRestartFrom( result.getTopologicallySortedProjects(), project ) ).toString() );
+                    + getResumeFrom( result.getTopologicallySortedProjects(), project ) ).toString() );
             }
 
             if ( MavenExecutionRequest.REACTOR_FAIL_NEVER.equals( cliRequest.request.getReactorFailureBehavior() ) )
@@ -1028,22 +1028,22 @@ public class MavenCli
     }
 
     /**
      * A helper method to determine the value to restart the build with <code>-rf</code> taking into account edge case
      * where multiple modules in reactor have the same artifactId.
      * <p>
-     * <code>-rf :artifactId</code> will pick up first module which matches, but when multiple modules in reactor
-     * have the same artifactId, effective failed module might be later in build reactor.
-     * This means that developer will either have to type group id or wait for build execution of all
-     * modules which were fine, but they are still before one which reported errors.
-     * <p>Then the returned value is <code>groupId:artifactId</code> when there is a name clash and
-     * <code>:artifactId</code> if there is no conflict.
+     * {@code -rf :artifactId} will pick up the first module which matches, but when multiple modules in the
+     * reactor have the same artifactId, effective failed module might be later in build reactor.
+     * This means that developer will either have to type groupId or wait for build execution of all modules
+     * which were fine, but they are still before one which reported errors.
+     * <p>Then the returned value is {@code groupId:artifactId} when there is a name clash and
+     * {@code :artifactId} if there is no conflict.
      *
      * @param mavenProjects Maven projects which are part of build execution.
      * @param failedProject Project which has failed.
      * @return Value for -rf flag to restart build exactly from place where it failed (<code>:artifactId</code> in
      *    general and <code>groupId:artifactId</code> when there is a name clash).
      */
-    private String getRestartFrom( List<MavenProject> mavenProjects, MavenProject failedProject )
+    private String getResumeFrom( List<MavenProject> mavenProjects, MavenProject failedProject )
     {
         for ( MavenProject buildProject : mavenProjects )
         {
@@ -1028,22 +1028,22 @@ public class MavenCli
 
     /**
-     * A helper method to determine the value to restart the build with <code>-rf</code> taking into account edge case
-     * where multiple modules in reactor have the same artifactId.
+     * A helper method to determine the value to resume the build with {@code -rf} taking into account the
+     * edge case where multiple modules in the reactor have the same artifactId.
      * <p>
@@ -1028,22 +1028,22 @@ public class MavenCli
      * @param mavenProjects Maven projects which are part of build execution.
      * @param failedProject Project which has failed.
-     * @return Value for -rf flag to restart build exactly from place where it failed (<code>:artifactId</code> in
-     *    general and <code>groupId:artifactId</code> when there is a name clash).
+     * @return Value for -rf flag to resume build exactly from place where it failed ({@code :artifactId} in
+     *    general and {@code groupId:artifactId} when there is a name clash).
      */

-- 
To stop receiving notification emails like this one, please contact
michaelo@apache.org.